@@ -6,7 +6,14 @@ import time
 import os
 import glob
 import numpy as np
-from . import strings, clock, download
+from . import strings as cc_strings
+from . import clock as cc_clock
+from . import download as cc_download
+# from . import strings, clock, download
+# import ccalafiore.strings
+# import ccalafiore.clock
+# import ccalafiore.download
+
 
 
 class MixamoBot:
@@ -31,16 +38,16 @@ class MixamoBot:
     def signup(self, email=None, password=None, first_name=None, last_name=None, birthday=None):
 
         if email is None:
-            email = strings.generate_a_random_email()
+            email = cc_strings.generate_a_random_email()
 
         if password is None:
-            password = strings.n_to_string_of_n_random_digits(n=10)
+            password = cc_strings.n_to_string_of_n_random_digits(n=10)
 
         if first_name is None:
-            first_name = strings.generate_a_random_name()
+            first_name = cc_strings.generate_a_random_name()
 
         if last_name is None:
-            last_name = strings.generate_a_random_name()
+            last_name = cc_strings.generate_a_random_name()
 
         if birthday is None:
             birthday = dict(day='1', month='1', year='1990')
@@ -65,7 +72,7 @@ class MixamoBot:
             'unt&el=true#/signup')
 
         self.driver.get(website_create_account)
-        timer = clock.Timer()
+        timer = cc_clock.Timer()
         job_done = False
         while not job_done:
             try:
@@ -96,7 +103,7 @@ class MixamoBot:
 
     def login(self, username, password):
         # click LOG IN
-        timer = clock.Timer()
+        timer = cc_clock.Timer()
         job_done = False
         while not job_done:
             try:
@@ -107,7 +114,7 @@ class MixamoBot:
                     raise TimeoutError('I cannot find the "Log in" button')
                 time.sleep(1)
 
-        timer = clock.Timer()
+        timer = cc_clock.Timer()
         job_done = False
         while not job_done:
             try:
@@ -122,7 +129,7 @@ class MixamoBot:
         time.sleep(0.2)
         self.driver.find_element_by_xpath("//span[contains(., 'Continue')]").click()
 
-        timer = clock.Timer()
+        timer = cc_clock.Timer()
         job_done = False
         while not job_done:
             try:
@@ -142,7 +149,7 @@ class MixamoBot:
 
     def activate_character(self, name_character, websites_search_actors):
 
-        timer = clock.Timer()
+        timer = cc_clock.Timer()
         job_done = False
         while not job_done:
             try:
@@ -157,7 +164,7 @@ class MixamoBot:
         if name_character.upper() != current_actor_name.upper():
             self.driver.get(websites_search_actors)
 
-            timer = clock.Timer()
+            timer = cc_clock.Timer()
             job_done = False
             while not job_done:
                 try:
@@ -168,7 +175,7 @@ class MixamoBot:
                         raise TimeoutError('I cannot find the character box')
                     time.sleep(1)
 
-            timer = clock.Timer()
+            timer = cc_clock.Timer()
             job_done = False
             while not job_done:
                 try:
@@ -184,7 +191,7 @@ class MixamoBot:
 
     def activate_character_old(self, name_character, search_actor_as):
 
-        timer = clock.Timer()
+        timer = cc_clock.Timer()
         job_done = False
         while not job_done:
             try:
@@ -198,7 +205,7 @@ class MixamoBot:
 
         if name_character.upper() != current_actor_name.upper():
             self.driver.get('https://www.mixamo.com/#/?page=1&type=Character')
-            timer = clock.Timer()
+            timer = cc_clock.Timer()
             job_done = False
             while not job_done:
                 try:
@@ -209,7 +216,7 @@ class MixamoBot:
                         raise TimeoutError('I cannot find the "search" box')
                     time.sleep(1)
 
-            timer = clock.Timer()
+            timer = cc_clock.Timer()
             job_done = False
             while not job_done:
                 try:
@@ -220,7 +227,7 @@ class MixamoBot:
                         raise TimeoutError('I cannot find the character box')
                     time.sleep(1)
 
-            timer = clock.Timer()
+            timer = cc_clock.Timer()
             job_done = False
             while not job_done:
                 try:
@@ -237,7 +244,7 @@ class MixamoBot:
             self, websites_animation, n_search_results_expected, i_search_result):
 
         self.driver.get(websites_animation)
-        timer = clock.Timer()
+        timer = cc_clock.Timer()
         elements_animations = self.driver.find_elements_by_css_selector('div.product-overlay')
         n_animation_elements_from_web = len(elements_animations)
         while n_animation_elements_from_web != n_search_results_expected:
@@ -261,7 +268,7 @@ class MixamoBot:
         while n_frames_default_from_web == n_frames_default_expected:
             n_frames_default_from_web -= 1
 
-        timer = clock.Timer()
+        timer = cc_clock.Timer()
 
         while n_frames_default_from_web != n_frames_default_expected:
 
@@ -294,7 +301,7 @@ class MixamoBot:
                 continue
 
     def get_n_frames_from_web(self, time_out=120):
-        timer = clock.Timer()
+        timer = cc_clock.Timer()
         n_frames_from_web_old = -2
         n_frames_from_web = -1
         while n_frames_from_web != n_frames_from_web_old:
@@ -405,7 +412,7 @@ class MixamoBot:
         # self.driver.find_element_by_css_selector('button.btn-block.btn.btn-primary').click()
         self.driver.find_element_by_xpath("//button[contains(., 'Download')]").click()
 
-        timer = clock.Timer()
+        timer = cc_clock.Timer()
         job_done = False
         while not job_done:
             try:
@@ -443,7 +450,7 @@ class MixamoBot:
         # download_elements[1].click()
         self.driver.find_elements_by_xpath("//button[contains(., 'Download')]")[1].click()
 
-        download.wait_downloading(saved_fbx_as, max_seconds_wait=180)
+        cc_download.wait_downloading(saved_fbx_as, max_seconds_wait=180)
 
         list_fbx_to_move = glob.glob(os.path.join(self.directory_downloads, '*.fbx'))
         n_fbx_to_move = len(list_fbx_to_move)
@@ -457,7 +464,7 @@ class MixamoBot:
         # self.driver.find_element_by_css_selector('button.btn-block.btn.btn-primary').click()
         self.driver.find_element_by_xpath("//button[contains(., 'Download')]").click()
 
-        timer = clock.Timer()
+        timer = cc_clock.Timer()
         job_done = False
         while not job_done:
             try:
@@ -487,7 +494,7 @@ class MixamoBot:
         # download_elements[1].click()
         self.driver.find_elements_by_xpath("//button[contains(., 'Download')]")[1].click()
 
-        timer = clock.Timer()
+        timer = cc_clock.Timer()
         while n_fbx_to_rename != 1:
             if timer.get_time() > timeout_dowloading:
                 raise TimeoutError('actor was not downloaded')
