@@ -17,6 +17,10 @@ from . import array as cc_array
 from . import maths as cc_maths
 from . import combinations as cc_combinations
 from .strings import format_float_to_str as cc_strings_format_float_to_str
+# import ccalafiore.array
+# import ccalafiore.maths
+# import ccalafiore.combinations
+# import ccalafiore.strings
 
 
 class Time:
@@ -140,7 +144,8 @@ class Loader:
             self.combinations_directories[:, self.time.level] += self.time.shift
         else:
             self.combinations_directories_no_shift = None
-            self.combinations_directories = cc_combinations.conditions_to_combinations(self.conditions_directories)
+            self.combinations_directories = (
+                cc_combinations.conditions_to_combinations(self.conditions_directories))
 
         self.labels = torch.tensor(
             self.combinations_directories[slice(0, self.n_samples, 1), self.level_classes],
