@@ -1,7 +1,7 @@
 import numpy as np
 import sys
 from ..maths import convert_to_int_or_float, convert_to_int
-from ..array import MyRange
+from ..array import Range
 from ..combinations import (
     conditions_to_combinations_on_the_fly_with_indexes as
     cc_conditions_to_combinations_on_the_fly_with_indexes)
@@ -382,7 +382,7 @@ class Frame:
             area_sources=None, special_flags=0):
 
         n_sources = len(sources)
-        myrange = MyRange(range_x)
+        myrange = Range(range_x)
         alignment_x_low = alignment_x.lower()
         if alignment_x_low in ['c', 'center', 'centre']:
             points_x = myrange.centers_of_n_within_equal_ranges(n_sources)
